==> pollen-ui-struts2-1.5.4-sources.jar: org/chorem/pollen/ui/actions/poll/form/EditPoll.java <==
/*
 * #%L
 * Pollen :: UI (struts2)
 * $Id: EditPoll.java 3611 2012-08-13 14:11:15Z tchemit $
 * $HeadURL: http://svn.chorem.org/svn/pollen/tags/pollen-1.5.4/pollen-ui-struts2/src/main/java/org/chorem/pollen/ui/actions/poll/form/EditPoll.java $
 * %%
 * Copyright (C) 2009 - 2012 CodeLutin, Tony Chemit
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.chorem.pollen.ui.actions.poll.form;

import org.chorem.pollen.business.persistence.Poll;
import org.chorem.pollen.services.exceptions.PollNotFoundException;

/**
 * Edit a poll (load it via {@link #input()}), and save it
 * via {@link #execute()}).
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.3
 */
public class EditPoll extends AbstractPollForm {

    private static final long serialVersionUID = 1L;

    @Override
    public boolean isClone() {

        // in edit mode never can be a clone
        return false;
    }

    @Override
    public boolean isEdit() {
        return true;
    }

    @Override
    protected Poll savePoll(Poll poll) throws PollNotFoundException {
        poll = getPollService().updatePoll(poll);
        addFlashMessage(_("pollen.information.poll.updated", poll.getTitle()));
        return poll;
    }

}

==> pollen-ui-struts2-1.5.5-sources.jar: org/chorem/pollen/ui/actions/poll/form/EditPoll.java <==
/*
 * #%L
 * Pollen :: UI (struts2)
 * $Id: EditPoll.java 3858 2013-12-07 08:00:40Z tchemit $
 * $HeadURL: http://svn.chorem.org/svn/pollen/tags/pollen-1.5.5/pollen-ui-struts2/src/main/java/org/chorem/pollen/ui/actions/poll/form/EditPoll.java $
 * %%
 * Copyright (C) 2009 - 2012 CodeLutin, Tony Chemit
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.chorem.pollen.ui.actions.poll.form;

import org.chorem.pollen.business.persistence.Poll;
import org.chorem.pollen.services.exceptions.PollNotFoundException;

import java.util.Date;

/**
 * Edit a poll (load it via {@link #input()}), and save it
 * via {@link #execute()}).
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.3
 */
public class EditPoll extends AbstractPollForm {

    private static final long serialVersionUID = 1L;

    @Override
    public boolean isClone() {

        // in edit mode never can be a clone
        return false;
    }

    @Override
    public boolean isEdit() {
        return true;
    }

    @Override
    protected Poll savePoll(Poll poll) throws PollNotFoundException {
        poll = getPollService().updatePoll(poll);
        addFlashMessage(_("pollen.information.poll.updated", poll.getTitle()));
        return poll;
    }

    @Override
    protected void validateChoiceDate(Date currentTime) {

        // --- beginChoicedate < endChoiceDate
        if (validateEndDate(poll.getBeginChoiceDate(), poll.getEndChoiceDate())) {

            addOptionsError(
                    "poll.endChoiceDate",
                    _("pollen.error.poll.endChoiceDate.before.beginChoiceDate"));
        }

        // --- endChoiceDate < endDate
        if (validateEndDate(poll.getEndChoiceDate(), poll.getEndDate())) {

            addOptionsError("poll.endChoiceDate",
                            _("pollen.error.poll.endChoiceDate.after.endDate"));
        }
    }

}
